@@ -51,12 +51,12 @@ def for_dl_video(url,download_directory=None,output_filename=None,get_info=None,
     download_directory =bool_or_default(download_directory,default=os.getcwd())
     get_info = bool_or_default(get_info,default=True)
     download_video =bool_or_default(download_video,default=True)
-    meta_data  = get_metas(url) or {}
-    logger.info(meta_data)
+
     kwargs = {"download_directory":download_directory,"output_filename":output_filename,"get_info":get_info,"download_video":download_video}
     for func in [for_dl_soup_vid,get_dl_vid]:
         context = {}
         try:
+
             video_info = func(url,**kwargs)
             for key in ['file_path','id']:
                 value = make_list(get_any_value(video_info,key) or None)[0]
@@ -68,6 +68,8 @@ def for_dl_video(url,download_directory=None,output_filename=None,get_info=None,
                 file_path = video_info.get('file_path')
                 ext = os.path.splitext(file_path)[-1]
                 file_id = video_info.get('id')
+                meta_data  = get_metas(url) or {}
+                logger.info(meta_data)
                 for key,value in meta_data.items():
                     if isinstance(value,dict):
                         context.update(value)
@@ -156,7 +158,7 @@ def get_url_list(urls = []):
             string = 'http'
         for piece in url.split('http'):
             string += piece
-            string = clean_url(string)
+            string = normalize_threads_url(string)
             url_list.append(string.split('?')[0])
             string = 'http'
             
@@ -216,14 +218,14 @@ def validate_video_urls(urls,
                 return output_urls[-1]
                     
     return output_urls
-def clean_url(urls):
-    init_typ = type(urls)
-    urls = make_list(urls  or [])
-    for i,url in enumerate(urls):
-        urls[i] = url.replace('threads.com','threads.net')
-    if urls and init_typ != list:
-        urls = urls[0]
-    return urls
+
+def normalize_threads_url(u: str) -> str:
+    p = urlparse(u)
+    if p.netloc in {"threads.com", "www.threads.com"}:
+        p = p._replace(netloc="www.threads.net")  # fallback for older extractors
+        return urlunparse(p)
+    return u
+
     
 def get_bolshevid_videos(url,
                         get_info_url=True,
@@ -232,15 +234,7 @@ def get_bolshevid_videos(url,
                         output_filename=None,
                         get_info=True,
                         download_video=True):
-    video_info = for_dl_video(
-                            url,
-                            download_directory=download_directory,
-                            output_filename=output_filename,
-                            get_info=get_info,
-                            download_video=download_video
-                            )
-    if video_info and isinstance(video_info,dict) and video_info != {}:
-        return video_info
+
     urls = deriveUrlList(url)
     video_urls = validate_video_urls(urls,
                         get_info_url=get_info_url,
